async fn apply_batch(
sink_id: GlobalId,
corrections: OkErr<Correction<Row>, Correction<DataflowErrorSer>>,
batch: BatchUpdates,
) -> OkErr<Correction<Row>, Correction<DataflowErrorSer>>Expand description
Apply a coalesced batch of updates to the correction buffers, on a blocking thread.
See apply_command for why this work must not run on a Tokio worker thread.